@@ -2,11 +2,11 @@
 # -*- coding:utf-8 -*-
 
 import re
-from .log_support import logger
 from functools import lru_cache
-from typing import Sequence, Collection
+from typing import Sequence, Collection, Union
 from executor.sql_support import require_limit
 from executor import get, query, select, DBError, Engine
+from .log_support import logger
 from .constant import CACHE_SIZE, LIMIT_1, DEFAULT_KEY_FIELD, MYSQL_COLUMN_SQL, MYSQL_SELECT_KEY, POSTGRES_COLUMN_SQL,\
     SQLITE_SELECT_KEY
 
@@ -46,7 +46,12 @@ class BaseDialect:
 
     @staticmethod
     def get_truncate_sql(table_name: str):
-        return 'TRUNCATE TABLE %s' % table_name
+        return 'TRUNCATE TABLE %s' % Dialect.get_dialect_str(table_name)
+
+    @staticmethod
+    def get_dialect_str(src: Union[str, int, Collection[str]]):
+        assert isinstance(src, str), 'source must be a string.'
+        return src.strip() if isinstance(src, str) else ','.join([s.strip() for s in src])
 
     @staticmethod
     def get_select_key(*args, **kwargs):
@@ -78,8 +83,11 @@ class MySQLDialect(BaseDialect):
         return MYSQL_SELECT_KEY
 
     @staticmethod
-    def get_truncate_sql(table_name: str):
-        return 'TRUNCATE TABLE `%s`' % table_name
+    def get_dialect_str(src: Union[str, int, Collection[str]]):
+        assert src, 'src is required.'
+        if isinstance(src, str):
+            return _dialect_str(src)
+        return ','.join([_dialect_str(arg) for arg in src])
 
 
 class PostgresDialect(BaseDialect):
@@ -133,12 +141,12 @@ class OracleDialect(BaseDialect):
         return ','.join([result[0] for result in results])
 
 
-class SQLiteDialect(BaseDialect):
+class SQLiteDialect(MySQLDialect):
 
     @staticmethod
     def get_table_columns(table_name: str):
-        results = query(f'PRAGMA table_info({table_name})')
-        return ','.join([result['name'] for result in results])
+        results = query(f'PRAGMA table_info(`{table_name}`)')
+        return ','.join(['`{}`'.format(result['name']) for result in results])
 
     @staticmethod
     def get_select_key(*args, **kwargs):
@@ -200,12 +208,34 @@ class Dialect:
         global _DIALECT
         return _DIALECT.get_truncate_sql(table_name)
 
+    @staticmethod
+    def get_drop_sql(table_name: str):
+        global _DIALECT
+        return _DIALECT.get_drop_sql(table_name)
+
     @staticmethod
     def get_select_key(*args, **kwargs):
         global _DIALECT
         return _DIALECT.get_select_key(*args, **kwargs)
 
+    @staticmethod
+    def get_dialect_str(src: Union[str, int, Collection[str]]):
+        global _DIALECT
+        return _DIALECT.get_dialect_str(src)
+
     @staticmethod
     def curr_engine():
         global _DIALECT
         return _DIALECT.engine
+
+
+def _dialect_str(src: Union[str, int]):
+    assert isinstance(src, str) or isinstance(src, int), 'source must be a string or int.'
+    if isinstance(src, int):
+        return str(src)
+    elif ',' in src:
+        return ','.join(['`{}`'.format(s.strip()) for s in src.split(',')])
+    elif '(' in src:
+        return src.strip()
+    else:
+        return '`{}`'.format(src.strip())
